@@ -23,7 +23,7 @@ import java.util.Map;
 import javax.inject.Inject;
 import javax.inject.Singleton;
 import org.eclipse.che.api.core.ApiException;
-import org.eclipse.che.api.factory.server.RawDevfileUrlFactoryParameterResolver;
+import org.eclipse.che.api.factory.server.FactoryParametersResolver;
 import org.eclipse.che.api.factory.server.scm.PersonalAccessTokenManager;
 import org.eclipse.che.api.factory.server.urlfactory.ProjectConfigDtoMerger;
 import org.eclipse.che.api.factory.server.urlfactory.RemoteFactoryUrl;
@@ -45,11 +45,13 @@ import org.eclipse.che.api.workspace.shared.dto.devfile.SourceDto;
  * @author Anatolii Bazko
  */
 @Singleton
-public class AzureDevOpsFactoryParametersResolver extends RawDevfileUrlFactoryParameterResolver {
+public class AzureDevOpsFactoryParametersResolver implements FactoryParametersResolver {
 
   /** Parser which will allow to check validity of URLs and create objects. */
   private final AzureDevOpsURLParser azureDevOpsURLParser;
 
+  private final URLFetcher urlFetcher;
+  private final URLFactoryBuilder urlFactoryBuilder;
   private final PersonalAccessTokenManager personalAccessTokenManager;
   private final ProjectConfigDtoMerger projectConfigDtoMerger;
 
@@ -60,8 +62,9 @@ public class AzureDevOpsFactoryParametersResolver extends RawDevfileUrlFactoryPa
       URLFetcher urlFetcher,
       URLFactoryBuilder urlFactoryBuilder,
       PersonalAccessTokenManager personalAccessTokenManager) {
-    super(urlFactoryBuilder, urlFetcher);
     this.azureDevOpsURLParser = azureDevOpsURLParser;
+    this.urlFetcher = urlFetcher;
+    this.urlFactoryBuilder = urlFactoryBuilder;
     this.personalAccessTokenManager = personalAccessTokenManager;
     this.projectConfigDtoMerger = projectConfigDtoMerger;
   }
