@@ -80,7 +80,7 @@ public class AuthorizingFileContentProvider<T extends RemoteFactoryUrl>
         String authorization;
         if (isNullOrEmpty(credentials)) {
           PersonalAccessToken token =
-              personalAccessTokenManager.get(remoteFactoryUrl.getHostName());
+              personalAccessTokenManager.getAndStore(remoteFactoryUrl.getProviderUrl());
           authorization =
               formatAuthorization(
                   token.getToken(),
@@ -92,7 +92,7 @@ public class AuthorizingFileContentProvider<T extends RemoteFactoryUrl>
         return urlFetcher.fetch(requestURL, authorization);
       }
     } catch (UnknownScmProviderException e) {
-      return fetchContentWithoutToken(requestURL, e);
+      return fetchContentWithoutToken(requestURL);
     } catch (ScmCommunicationException e) {
       return toIOException(fileURL, e);
     } catch (ScmUnauthorizedException
@@ -102,7 +102,7 @@ public class AuthorizingFileContentProvider<T extends RemoteFactoryUrl>
     }
   }
 
-  protected String fetchContentWithoutToken(String requestURL, UnknownScmProviderException e)
+  protected String fetchContentWithoutToken(String requestURL)
       throws DevfileException, IOException {
     // we don't have any provider matching this SCM provider
     // so try without secrets being configured
@@ -123,7 +123,7 @@ public class AuthorizingFileContentProvider<T extends RemoteFactoryUrl>
         }
       }
       throw new DevfileException(
-          String.format("%s: %s", e.getMessage(), exception.getMessage()), exception);
+          "Could not reach devfile at " + "`" + exception.getMessage() + "`", exception);
     }
   }
 
